@@ -7,7 +7,6 @@ from abc import (
     ABC,
     abstractmethod,
 )
-from pathlib import Path
 
 import cv2
 
@@ -17,7 +16,7 @@ from sail_utils import LOGGER
 class _Streamer(ABC):
 
     def __init__(self, source: str, rate: float):
-        self._source = Path(source)
+        self._source = source
         self._rate = rate
         self._stream = None
 
@@ -27,7 +26,7 @@ class _Streamer(ABC):
         get the source
         :return:
         """
-        return self._source.as_posix()
+        return self._source
 
     @property
     def rate(self) -> float:
@@ -45,6 +44,12 @@ class _Streamer(ABC):
         """
         return self._stream
 
+    def __enter__(self):
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self._stream.release()
+
 
 class _Detector(ABC):
 
