@@ -3,20 +3,27 @@
 test module for audio spectrum analysis
 """
 
-import unittest.mock as mock
 from pathlib import Path
 
+import numpy as np
+import pandas as pd
 from pytest import fixture
+
 from sail_utils.audio.spectrum import FreqAnalysis
 
 
 @fixture(name="freq_analysis")
-def freq_analysis_fixture():
+def _freq_analysis_fixture():
     file_path = Path(__file__).absolute().parents[1] / "data/1586915489.wav"
     return FreqAnalysis(file_path.as_posix())
 
 
 def test_freq_analysis_freq_features(freq_analysis):
+    """
+    test freq_features in FreqAnalysis
+    :param freq_analysis:
+    :return:
+    """
     buckets = [[0, 50],
                [500, 800],
                [950, 1050],
@@ -35,3 +42,13 @@ def test_freq_analysis_freq_features(freq_analysis):
     freq, spec = freq_analysis.spectrum(start_offset=start_offset,
                                         window=window,
                                         cutoff=cutoff)
+    freq_series = pd.Series(data=np.abs(spec), index=freq)
+
+    expected = []
+    for bucket in buckets:
+        width = bucket[1] - bucket[0]
+        selected_freq = freq_series[bucket[0]:bucket[1]]
+        expected.append(np.sum(selected_freq) / width)
+
+    expected = np.array(expected)
+    np.testing.assert_array_almost_equal(calculated, expected)
