@@ -12,9 +12,8 @@ from sail_utils.cv.frame import (
 )
 
 
-@mock.patch("time.time", return_value="150000")
 @mock.patch("cv2.VideoCapture")
-def test_live_streamer_init(mocked_video, mocked_time):
+def test_live_streamer_init(mocked_video, ):
     """
     test live streamer construction
     :param mocked_video:
@@ -24,7 +23,6 @@ def test_live_streamer_init(mocked_video, mocked_time):
     streamer = LiveStreamer(source="test_stream",
                             rate=15)
 
-    assert mocked_time() == streamer.current_time
     assert mocked_video is cv2.VideoCapture
     assert streamer.rate == 15
 
